pyvtt
=============

pyvtt is a Python library used to edit or create WebVTT files.

It is basically a port of pysrt <https://github.com/byroot/pysrt>, another
Python library to manage SubRip files written by Jean Boussier <https://github.com/byroot>.

.. image:: https://travis-ci.org/guillemcabrera/pyvtt.svg?branch=master
  :target: http://travis-ci.org/guillemcabrera/pyvtt
.. image:: https://coveralls.io/repos/github/guillemcabrera/pyvtt/badge.svg?branch=master
  :target: https://coveralls.io/github/guillemcabrera/pyvtt?branch=master